========
Temporal
========

The following methods are available under the `Series.dt` attribute.

.. currentmodule:: polars
.. autosummary::
   :toctree: api/
   :template: autosummary/accessor_method.rst

    Series.dt.base_utc_offset
    Series.dt.cast_time_unit
    Series.dt.replace_time_zone
    Series.dt.combine
    Series.dt.date
    Series.dt.datetime
    Series.dt.day
    Series.dt.days
    Series.dt.dst_offset
    Series.dt.epoch
    Series.dt.hour
    Series.dt.hours
    Series.dt.is_leap_year
    Series.dt.iso_year
    Series.dt.max
    Series.dt.mean
    Series.dt.median
    Series.dt.microsecond
    Series.dt.microseconds
    Series.dt.millisecond
    Series.dt.milliseconds
    Series.dt.min
    Series.dt.minute
    Series.dt.minutes
    Series.dt.month
    Series.dt.month_start
    Series.dt.month_end
    Series.dt.nanosecond
    Series.dt.nanoseconds
    Series.dt.offset_by
    Series.dt.ordinal_day
    Series.dt.quarter
    Series.dt.round
    Series.dt.second
    Series.dt.seconds
    Series.dt.strftime
    Series.dt.time
    Series.dt.timestamp
    Series.dt.to_string
    Series.dt.total_days
    Series.dt.total_hours
    Series.dt.total_microseconds
    Series.dt.total_milliseconds
    Series.dt.total_minutes
    Series.dt.total_nanoseconds
    Series.dt.total_seconds
    Series.dt.truncate
    Series.dt.week
    Series.dt.weekday
    Series.dt.with_time_unit
    Series.dt.convert_time_zone
    Series.dt.year
